# pyffstream

[![PyPI](https://img.shields.io/pypi/v/pyffstream.svg)](https://pypi.org/project/pyffstream/)
[![Python](https://img.shields.io/pypi/pyversions/pyffstream.svg)](https://pypi.org/project/pyffstream/)
[![Docs](https://readthedocs.org/projects/pyffstream/badge/)](https://pyffstream.readthedocs.io/)
[![Release](https://github.com/gbeauregard/pyffstream/workflows/Release/badge.svg)](https://github.com/GBeauregard/pyffstream/actions/workflows/release.yml)
[![Tox](https://github.com/gbeauregard/pyffstream/workflows/Tox/badge.svg)](https://github.com/GBeauregard/pyffstream/actions/workflows/tox.yml)
[![CodeQL](https://github.com/gbeauregard/pyffstream/workflows/CodeQL/badge.svg)](https://github.com/GBeauregard/pyffstream/actions/workflows/codeql-analysis.yml)
[![Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A CLI wrapper for ffmpeg to stream files over SRT/RTMP. Also supports the api
for a not (yet) open sourced pyffserver endpoint.

## Usage

See [the documentation](https://pyffstream.readthedocs.io/) for a list of CLI options.


## Notes

The CLI interface is relatively stable, but the API helper functions are
subject to change drastically until at least 0.1.
